@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use URI;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -149,6 +149,17 @@ sub copy {
     return $self->drv_copy($src, $dest);
 }
 
+=head2 exists($file)
+
+Return True if $file exists on the VFS
+
+=cut
+
+sub exists {
+    my ($self, $file) = @_;
+    return $self->drv_exists($file);
+}
+
 1;
 
 __END__
